@@ -775,6 +775,12 @@ class ABSLHandler(logging.Handler):
     super(ABSLHandler, self).close()
     self._current_handler.close()
 
+  def handle(self, record):
+    rv = self.filter(record)
+    if rv:
+      return self._current_handler.handle(record)
+    return rv
+
   @property
   def python_handler(self):
     return self._python_handler
@@ -843,7 +849,9 @@ class ABSLLogger(logging.getLoggerClass()):
       (filename, lineno, methodname[, sinfo]) of the calling method.
     """
     f_to_skip = ABSLLogger._frames_to_skip
-    frame = logging.currentframe()
+    # Use sys._getframe(2) instead of logging.currentframe(), it's slightly
+    # faster because there is one less frame to traverse.
+    frame = sys._getframe(2)  # pylint: disable=protected-access
 
     while frame:
       code = frame.f_code
